@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2022 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -36,3 +36,15 @@ void predecessor_graph(GraphInterface& gi, GraphInterface& gpi,
          },
          vertex_scalar_properties())(pred_map);
 }
+
+#include <boost/python.hpp>
+
+using namespace boost::python;
+
+#define __MOD__ generation
+#include "module_registry.hh"
+REGISTER_MOD
+([]
+ {
+     def("predecessor_graph", &predecessor_graph);
+ });
