@@ -1,6 +1,6 @@
 // graph-tool -- a general graph modification and manipulation thingy
 //
-// Copyright (C) 2006-2022 Tiago de Paula Peixoto <tiago@skewed.de>
+// Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
 //
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU Lesser General Public License as published by the Free
@@ -307,7 +307,7 @@ python::object get_edge(GraphInterface& gi, size_t s, size_t t, bool all_edges)
                  (std::forward<decltype(graph)>(graph), gi, s, t, all_edges,
                   es);
          })();
-    return std::move(es);
+    return es;
 }
 
 
