@@ -3,7 +3,7 @@
 #
 # graph_tool -- a general graph manipulation python module
 #
-# Copyright (C) 2006-2022 Tiago de Paula Peixoto <tiago@skewed.de>
+# Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -19,16 +19,17 @@
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 """
-``graph_tool.centrality`` - Centrality measures
------------------------------------------------
+``graph_tool.centrality``
+-------------------------
 
-This module includes centrality-related algorithms.
+This module provides centrality-related algorithms.
 
 Summary
 +++++++
 
 .. autosummary::
    :nosignatures:
+   :toctree: autosummary
 
    pagerank
    betweenness
@@ -40,8 +41,6 @@ Summary
    eigentrust
    trust_transitivity
 
-Contents
-++++++++
 """
 
 from .. dl_import import dl_import
