@@ -19,17 +19,17 @@
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
 """
-``graph_tool.draw`` - Graph drawing and layout
-----------------------------------------------
+``graph_tool.draw``
+-------------------
 
-Summary
-+++++++
+This module contains functions for graph drawing and layout.
 
 Layout algorithms
 =================
 
 .. autosummary::
    :nosignatures:
+   :toctree: autosummary
 
    sfdp_layout
    fruchterman_reingold_layout
@@ -43,6 +43,7 @@ Graph drawing
 
 .. autosummary::
    :nosignatures:
+   :toctree: autosummary
 
    graph_draw
    draw_hierarchy
@@ -56,14 +57,19 @@ Low-level graph drawing
 
 .. autosummary::
    :nosignatures:
+   :toctree: autosummary
 
    cairo_draw
    interactive_window
+
+.. autosummary::
+   :nosignatures:
+   :toctree: autosummary
+   :template: class-no-inherit.rst
+
    GraphWidget
    GraphWindow
 
-Contents
-++++++++
 """
 
 from .. import Graph, GraphView, _check_prop_vector, _check_prop_scalar, \
@@ -360,11 +366,11 @@ def arf_layout(g, weight=None, d=0.5, a=10, dt=0.001, epsilon=1e-6,
     .. testcode::
        :hide:
 
-       np.random.seed(42)
-       gt.seed_rng(42)
+       np.random.seed(43)
+       gt.seed_rng(45)
 
     >>> g = gt.price_network(300)
-    >>> pos = gt.arf_layout(g, max_iter=0)
+    >>> pos = gt.arf_layout(g)
     >>> gt.graph_draw(g, pos=pos, output="graph-draw-arf.pdf")
     <...>
 
@@ -388,7 +394,7 @@ def arf_layout(g, weight=None, d=0.5, a=10, dt=0.001, epsilon=1e-6,
     """
 
     if pos is None:
-        pos = random_layout(g, dim=dim)
+        pos = random_layout(g, dim=dim, shape=[[0, 1]] * dim)
     _check_prop_vector(pos, name="pos", floating=True)
 
     ug = GraphView(g, directed=False)
