@@ -3,7 +3,7 @@
 #
 # graph_tool -- a general graph manipulation python module
 #
-# Copyright (C) 2006-2022 Tiago de Paula Peixoto <tiago@skewed.de>
+# Copyright (C) 2006-2023 Tiago de Paula Peixoto <tiago@skewed.de>
 #
 # This program is free software; you can redistribute it and/or modify it under
 # the terms of the GNU Lesser General Public License as published by the Free
@@ -20,8 +20,8 @@
 
 from .. import _prop, Graph, GraphView, _get_rng, PropertyMap, \
     edge_endpoint_property, Vector_size_t
-from .. generation import generate_triadic_closure
-from .. stats import remove_parallel_edges,  remove_self_loops
+from .. generation import generate_triadic_closure, remove_parallel_edges, \
+    remove_self_loops
 from .. spectral import adjacency
 
 from .. dl_import import dl_import
@@ -251,8 +251,9 @@ class LatentClosureBlockState(LatentLayerBaseState):
 
     References
     ----------
-    .. [peixoto-disentangling-2021] Tiago P. Peixoto, "Disentangling homophily,
-       community structure and triadic closure in networks", :arxiv:`2101.02510`
+    .. [peixoto-disentangling-2022] Tiago P. Peixoto, "Disentangling homophily,
+       community structure and triadic closure in networks", Phys. Rev. X 12,
+       011004 (2022), :doi:`10.1103/PhysRevX.12.011004`, :arxiv:`2101.02510`
     """
 
     def __init__(self, g, L=1, b=None, aE=numpy.nan, nested=True,
@@ -333,6 +334,9 @@ class LatentClosureBlockState(LatentLayerBaseState):
         self.beta = fn_params.get("beta", 1)
         self.mu = fp_params.get("mu", 1)
         self.nu = fp_params.get("nu", 1)
+        self.lp = kwargs.get("lp", numpy.nan)
+        self.lq = kwargs.get("lq", numpy.nan)
+        self.max_w = kwargs.get("max_w", 1 << 16)
         self.self_loops = True
 
         if nested:
@@ -604,8 +608,9 @@ class MeasuredClosureBlockState(LatentClosureBlockState, UncertainBaseState):
 
     References
     ----------
-    .. [peixoto-disentangling-2021] Tiago P. Peixoto, "Disentangling homophily,
-       community structure and triadic closure in networks", :arxiv:`2101.02510`
+    .. [peixoto-disentangling-2022] Tiago P. Peixoto, "Disentangling homophily,
+       community structure and triadic closure in networks", Phys. Rev. X 12,
+       011004 (2022), :doi:`10.1103/PhysRevX.12.011004`, :arxiv:`2101.02510`
     """
 
     def __init__(self, g, n, x, n_default=1, x_default=0, L=1, b=None,
