@@ -93,20 +93,15 @@ def pmap(prop, value_map):
         a = prop.fa
     else:
         a = prop
+    if len(a) == 0:
+        return
     if isinstance(value_map, PropertyMap):
         value_map = value_map.fa
     if a.max() >= len(value_map):
         raise ValueError("value_map is not large enough!" +
                          " max val: %s, map size: %s" % (a.max(),
                                                          len(value_map)))
-    if a.dtype != value_map.dtype:
-        value_map = array(value_map, dtype=a.dtype)
-    if a.dtype == "int64":
-        libinference.vector_map64(a, value_map)
-    elif a.dtype == "float64":
-        libinference.vector_mapdouble(a, value_map)
-    else:
-        libinference.vector_map(a, value_map)
+    libinference.vector_map(a, value_map)
     if isinstance(prop, PropertyMap):
         prop.fa = a
 
@@ -124,12 +119,7 @@ def reverse_map(prop, value_map):
                          " max val: %s, map size: %s" % (prop.max(), len(a)))
     if prop.dtype != a.dtype:
         prop = array(prop, dtype=a.dtype)
-    if a.dtype == "int64":
-        libinference.vector_rmap64(prop, a)
-    elif a.dtype == "float64":
-        libinference.vector_rmapdouble(prop, a)
-    else:
-        libinference.vector_rmap(prop, a)
+    libinference.vector_rmap(prop, a)
     if isinstance(value_map, PropertyMap):
         value_map.fa = a
 
@@ -140,17 +130,7 @@ def contiguous_map(prop):
         a = prop.fa
     else:
         a = prop
-    if a.max() < len(a):
-        rmap = -ones(len(a), dtype=a.dtype)
-        if a.dtype == "int64":
-            libinference.vector_map64(a, rmap)
-        else:
-            libinference.vector_map(a, rmap)
-    else:
-        if a.dtype == "int64":
-            libinference.vector_contiguous_map64(a)
-        else:
-            libinference.vector_contiguous_map(a)
+    libinference.vector_contiguous_map(a)
     if isinstance(prop, PropertyMap):
         prop.fa = a
     return prop
